==> haskell-kvitable-1.1.0.1-62-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-kvitable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kvitable
version:              1.1.0.1
visibility:           public
id:                   kvitable-1.1.0.1-9cOi4k8wCvJ5xorR0RbDP
key:                  kvitable-1.1.0.1-9cOi4k8wCvJ5xorR0RbDP
license:              ISC
copyright:            Kevin Quick, 2021-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/kvitable
synopsis:             Key/Value Indexed Table container and formatting library
description:

    Allows creation of a table from a set of of Key+Value Indices.
    This differs from the standard '\''Map'\'' structure in that the '\''Map'\''
    simply indexes by value but the KVI table indexes by a
    heterogeneous list of keys along with their associated values.
    This effectively creates an N-dimensional table, where
    @N=Product(Count(Values[key]))@.  The table contents can be sparse.

    This library also provides the ability to format multi-dimensional
    data in a table presentation.  The table is automatically formatted
    and can be output in a number of different styles (ascii, html,
    etc.)

    Multi-dimensional data is more difficult to represent than simple
    two-dimensional data; this package provides the ability to select
    which dimensions should be represented as sub-rows and which
    dimensions should be represented as sub-columns.  See the README
    for examples

category:             Text
abi:                  f1e4144df85774b065e8fbfd30a1c0b1
exposed:              True
exposed-modules:
    Data.KVITable Data.KVITable.Internal.Helpers Data.KVITable.Render
    Data.KVITable.Render.ASCII Data.KVITable.Render.HTML
    Data.KVITable.Render.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kvitable-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kvitable-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kvitable-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kvitable
hs-libraries:         HSkvitable-1.1.0.1-9cOi4k8wCvJ5xorR0RbDP
depends:
    base-4.17.2.1 containers-0.6.7
    lucid-2.11.20250303-EuIfpEah6D49gRYj3KWxjX
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    named-text-1.2.1.0-CDlnEnVp1w0F7zFjZyNLOK
    sayable-1.2.5.0-Htl6e9utMda8m5li9o41ut text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-kvitable/html/kvitable.haddock
haddock-html:         /usr/share/doc/haskell-kvitable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kvitable-1.1.0.1-84-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-kvitable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kvitable
version:              1.1.0.1
visibility:           public
id:                   kvitable-1.1.0.1-Ji9RU6SxGfvLg2unxV8c9g
key:                  kvitable-1.1.0.1-Ji9RU6SxGfvLg2unxV8c9g
license:              ISC
copyright:            Kevin Quick, 2021-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/kvitable
synopsis:             Key/Value Indexed Table container and formatting library
description:

    Allows creation of a table from a set of of Key+Value Indices.
    This differs from the standard '\''Map'\'' structure in that the '\''Map'\''
    simply indexes by value but the KVI table indexes by a
    heterogeneous list of keys along with their associated values.
    This effectively creates an N-dimensional table, where
    @N=Product(Count(Values[key]))@.  The table contents can be sparse.

    This library also provides the ability to format multi-dimensional
    data in a table presentation.  The table is automatically formatted
    and can be output in a number of different styles (ascii, html,
    etc.)

    Multi-dimensional data is more difficult to represent than simple
    two-dimensional data; this package provides the ability to select
    which dimensions should be represented as sub-rows and which
    dimensions should be represented as sub-columns.  See the README
    for examples

category:             Text
abi:                  1359c7c1aba6900f6d5eb898e23b7b66
exposed:              True
exposed-modules:
    Data.KVITable Data.KVITable.Internal.Helpers Data.KVITable.Render
    Data.KVITable.Render.ASCII Data.KVITable.Render.HTML
    Data.KVITable.Render.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kvitable-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kvitable-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kvitable-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kvitable
hs-libraries:         HSkvitable-1.1.0.1-Ji9RU6SxGfvLg2unxV8c9g
depends:
    base-4.17.2.1 containers-0.6.7
    lucid-2.11.20250303-GXZ1Ug6xZHn2LHsZiS8N0D
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    named-text-1.2.1.0-GAFJH1Pik6ZHyojryDvg1H
    sayable-1.2.5.0-2tbdHmZEwmK2XWiyL5dl6A text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-kvitable/html/kvitable.haddock
haddock-html:         /usr/share/doc/haskell-kvitable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
